@@ -1,7 +1,8 @@
 import json
 from collections.abc import Sequence
 from http import HTTPStatus
-from typing import Any, TypeVar
+from typing import Any
+from typing_extensions import deprecated
 from uuid import UUID
 
 import httpx
@@ -12,17 +13,23 @@ from camunda_client.clients.endpoints import CamundaUrls
 from camunda_client.clients.engine.schemas.body import (
     ClaimTaskSchema,
     HistoricProcessInstanceFilterSchema,
+    HistoryVariableInstanceFilterSchema,
     SetAssigneeTaskSchema,
     UpdateProcessVariablesSchema,
 )
+from camunda_client.clients.engine.schemas.query import (
+    HistoryVariableInstanceFilterParamsSchema,
+)
 from camunda_client.clients.engine.schemas.response import (
     HistoricTaskInstanceSchema,
+    TaskIdentitySchema,
     TaskSchema,
     VariableInstanceSchema,
     HistoricProcessInstanceSchema,
 )
 from camunda_client.clients.schemas import CountSchema, PaginationParams
 from camunda_client.types_ import (
+    TValue,
     TypedVariableValueSchema,
     VariableValueSchema,
     Variables,
@@ -37,7 +44,7 @@ from .schemas import (
     StartProcessInstanceSchema,
     SendCorrelationMessageSchema,
 )
-from .dto import GetTaskVariableDTO
+from .dto import GetTaskVariableDTO, UpdateTaskVariableDTO
 
 
 PROCESS_INSTANCE_ADAPTER = TypeAdapter(list[ProcessInstanceSchema])
@@ -45,8 +52,7 @@ TASK_ADAPTER = TypeAdapter(list[TaskSchema])
 HISTORIC_TASK_INSTANCE_ADAPTER = TypeAdapter(list[HistoricTaskInstanceSchema])
 HISTORIC_PROCESS_INSTANCE_ADAPTER = TypeAdapter(list[HistoricProcessInstanceSchema])
 VARIABLE_INSTANCE_ADAPTER = TypeAdapter(list[VariableInstanceSchema])
-
-_T = TypeVar("_T")
+TASK_IDENTITY_ADAPTER = TypeAdapter(list[TaskIdentitySchema])
 
 
 class CamundaEngineClient:
@@ -207,6 +213,9 @@ class CamundaEngineClient:
         raise_for_status(response)
         return HISTORIC_PROCESS_INSTANCE_ADAPTER.validate_python(response.json())
 
+    @deprecated(
+        "Use `get_history_variable_instances` or `get_history_variable_instances_post` instead of this method. Will be removed later.",
+    )
     async def get_variable_instances(
         self,
         *,
@@ -216,7 +225,7 @@ class CamundaEngineClient:
         """Queries for historic variable instances that fulfill the given parameters."""
 
         response = await self._http_client.get(
-            self._urls.variable_instances,
+            self._urls.history_variable_instances,
             params={
                 "processInstanceId": str(process_instance_id),
                 "deserializeValues": deserialize_values,
@@ -225,6 +234,50 @@ class CamundaEngineClient:
         raise_for_status(response)
         return VARIABLE_INSTANCE_ADAPTER.validate_python(response.json())
 
+    async def get_history_variable_instances(
+        self,
+        filter_: HistoryVariableInstanceFilterParamsSchema | None = None,
+        pagination: PaginationParams | None = None,
+    ) -> Sequence[VariableInstanceSchema]:
+        """Queries for historic variable instances that fulfill the given parameters."""
+
+        filter_ = filter_ or HistoryVariableInstanceFilterParamsSchema(
+            deserialize_values=False
+        )
+        pagination_params = (
+            pagination.model_dump(mode="json", by_alias=True) if pagination else {}
+        )
+        response = await self._http_client.get(
+            self._urls.history_variable_instances,
+            params={
+                **pagination_params,
+                **filter_.model_dump(mode="json", by_alias=True, exclude_unset=True),
+            },
+        )
+        raise_for_status(response)
+        return VARIABLE_INSTANCE_ADAPTER.validate_python(response.json())
+
+    async def get_history_variable_instances_post(
+        self,
+        filter_: HistoryVariableInstanceFilterSchema | None = None,
+        pagination: PaginationParams | None = None,
+        *,
+        deserialize_values: bool = False,
+    ) -> Sequence[VariableInstanceSchema]:
+        """Queries for historic variable instances that fulfill the given parameters."""
+
+        filter_ = filter_ or HistoryVariableInstanceFilterSchema()
+        pagination_params = (
+            pagination.model_dump(mode="json", by_alias=True) if pagination else {}
+        )
+        response = await self._http_client.post(
+            self._urls.history_variable_instances,
+            params={"deserializeValues": deserialize_values, **pagination_params},
+            content=filter_.model_dump_json(by_alias=True, exclude_unset=True),
+        )
+        raise_for_status(response)
+        return VARIABLE_INSTANCE_ADAPTER.validate_python(response.json())
+
     async def update_variable_instances(
         self,
         *,
@@ -331,10 +384,11 @@ class CamundaEngineClient:
         self,
         dto: GetTaskVariableDTO,
     ) -> httpx.Response:
-        url = self._urls.get_task_variable(
-            task_id=str(dto.task_id),
-            variable_name=dto.variable_name,
-        )
+        url_resolver = self._urls.task_variable
+        if dto.is_local_variable:
+            url_resolver = self._urls.local_task_variable
+
+        url = url_resolver(task_id=str(dto.task_id), variable_name=dto.variable_name)
         return await self._http_client.get(
             url,
             params={"deserializeValue": dto.deserialize_value},
@@ -360,11 +414,12 @@ class CamundaEngineClient:
     async def get_typed_task_variable(
         self,
         dto: GetTaskVariableDTO,
-        variable_type: type[_T],
-    ) -> TypedVariableValueSchema[_T] | None:
+        variable_type: type[TValue],
+    ) -> TypedVariableValueSchema[TValue] | None:
         """
         Does the same thing as `get_task_variable`,
         except it casts value to the type specified in `variable_type`.
+        Note: If you expect to get a pydantic model as the result, set `deserialize_value` to False.
         """
         response = await self._get_task_variable(dto)
         if response.status_code == HTTPStatus.NOT_FOUND:
@@ -372,3 +427,33 @@ class CamundaEngineClient:
 
         raise_for_status(response)
         return TypedVariableValueSchema[variable_type].model_validate(response.json())
+
+    async def update_task_variable(
+        self,
+        dto: UpdateTaskVariableDTO,
+    ) -> None:
+        """
+        Updates a process variable that is visible from the Task scope.
+        A variable is visible from the task if it is a local task variable,
+        or declared in a parent scope of the task.
+        """
+        url_resolver = self._urls.task_variable
+        if dto.is_local_variable:
+            url_resolver = self._urls.local_task_variable
+
+        url = url_resolver(
+            task_id=str(dto.task_id),
+            variable_name=dto.variable_name,
+        )
+        content = dto.variable.model_dump_json(by_alias=True)
+        response = await self._http_client.put(url, content=content)
+        raise_for_status(response)
+
+    async def get_identity_links(
+        self,
+        task_id: UUID,
+    ) -> list[TaskIdentitySchema]:
+        url = self._urls.identity_links(str(task_id))
+        response = await self._http_client.get(url)
+        raise_for_status(response)
+        return TASK_IDENTITY_ADAPTER.validate_python(response.json())
