@@ -18,7 +18,6 @@ from camunda_client.types_ import TypedVariableValueSchema
             "29b34aa1-0eae-42d9-9e97-8b6c028e4841",
             UUID("29b34aa1-0eae-42d9-9e97-8b6c028e4841"),
         ),
-        (str, "888", "888"),
         (datetime, datetime.min.isoformat(), datetime.min),
     ],
 )
@@ -28,6 +27,8 @@ def test_typed(
     expected: Any,
 ) -> None:
     response = {"type": "String", "value": value, "valueInfo": {}}
-    schema = TypedVariableValueSchema[variable_type].model_validate(response)
+    schema = TypedVariableValueSchema[
+        variable_type  # type:ignore[valid-type]
+    ].model_validate(response)
     assert isinstance(schema.value, variable_type)
     assert schema.value == expected
